Converts a CellEngine object to its flowCore analogue.

toFlowCore(cellengineObject)

Arguments

cellengineObject

The CellEngine object to be converted.

Details

Notes: Split gates and quadrant gates will be converted to lists of two and four rectangle gates, respectively. Skewed quadrant gates from CellEngine will be converted to orthogonal quadrant gates, as flowCore's quadGate class does not support skewing.

Examples

if (FALSE) { # \dontrun{
# Converting a compensation:
ceComp <- getCompensation(experimentId, byName("My comp"))
fcComp <- toFlowCore(ceComp)
} # }