toFlowCore.RdConverts a CellEngine object to its flowCore analogue.
toFlowCore(cellengineObject)Notes: Split gates and quadrant gates will be converted to lists of two and four rectangle gates, respectively. Skewed quadrant gates from CellEngine will be converted to orthogonal quadrant gates, as flowCore's quadGate class does not support skewing.
if (FALSE) { # \dontrun{
# Converting a compensation:
ceComp <- getCompensation(experimentId, byName("My comp"))
fcComp <- toFlowCore(ceComp)
} # }